.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth API reference.

#############################
Testing TotalDepth
#############################

Contents:

.. toctree::
	:maxdepth: 2
	
	unit_tests
	test_plot
	test_set
